@@ -18,6 +18,8 @@
 
 #define GOVIRT_HTTPS_PORT 8088
 
+static GMutex run_mutex;
+
 struct GovirtMockHttpd {
     GThread *thread;
     GMainLoop *loop;
@@ -76,13 +78,13 @@ server_callback (SoupServer *server, SoupServerMessage *msg,
 	const char *content;
 	GovirtMockHttpd *mock_httpd = data;
 
-	g_debug ("%s %s HTTP/1.%d\n", soup_server_message_get_method(msg), path,
+	g_debug ("%s %s HTTP/1.%d", soup_server_message_get_method(msg), path,
 		 soup_server_message_get_http_version (msg));
 	soup_message_headers_iter_init (&iter, soup_server_message_get_request_headers(msg));
 	while (soup_message_headers_iter_next (&iter, &name, &value))
-		g_debug ("%s: %s\n", name, value);
+		g_debug ("%s: %s", name, value);
 	if (soup_server_message_get_request_body(msg)->length)
-		g_debug ("%s\n", soup_server_message_get_request_body(msg)->data);
+		g_debug ("%s", soup_server_message_get_request_body(msg)->data);
 
 	content = govirt_mock_httpd_find_request(mock_httpd, soup_server_message_get_method(msg), path);
 	if (content == NULL) {
@@ -138,13 +140,14 @@ govirt_httpd_run (gpointer user_data)
 	for (u = uris; u; u = u->next) {
 		char *str;
 		str = g_uri_to_string (u->data);
-		g_debug ("Listening on %s\n", str);
+		g_debug ("Listening on %s", str);
 		g_free (str);
 		g_uri_unref (u->data);
 	}
 	g_slist_free (uris);
 
-	g_debug ("\nWaiting for requests...\n");
+	g_debug ("Waiting for requests...\n");
+	g_mutex_unlock(&run_mutex);
 
 	g_main_loop_run (mock_httpd->loop);
 	g_main_context_pop_thread_default (context);
@@ -166,6 +169,7 @@ govirt_mock_httpd_new (guint port)
 	context = g_main_context_new ();
 	mock_httpd->loop = g_main_loop_new (context, TRUE);
 	g_main_context_unref (context);
+	g_mutex_lock(&run_mutex);
 
 	mock_httpd->requests = g_hash_table_new_full (g_str_hash, g_str_equal,
 						      NULL,
@@ -216,6 +220,7 @@ govirt_mock_httpd_start (GovirtMockHttpd *mock_httpd)
 
 	mock_httpd->thread = g_thread_new ("simple-soup-httpd",
 					   govirt_httpd_run, mock_httpd);
+	g_mutex_lock(&run_mutex);
 }
 
 
@@ -251,4 +256,5 @@ govirt_mock_httpd_stop (GovirtMockHttpd *mock_httpd)
 	g_hash_table_unref (mock_httpd->requests);
 	g_main_loop_unref (mock_httpd->loop);
 	g_free (mock_httpd);
+	g_mutex_unlock(&run_mutex);
 }
